@@ -1,5 +1,5 @@
 if (!exists("Reporter")) {
-  Reporter <- Object$clone()
+  Reporter <- mutatr::Object$clone()
     SummaryReporter <- Reporter$clone()
     StopReporter <- Reporter$clone()  
     MinimalReporter <- Reporter$clone()  
