@@ -12,7 +12,7 @@
 #'    rerun
 #'  \item otherwise, each new or modified test is run
 #' }
-#' In the future, \code{auto_test} might implement on of the following more 
+#' In the future, \code{auto_test} might implement one of the following more 
 #' intelligent alternatives:
 #' 
 #' \itemize{
@@ -20,7 +20,7 @@
 #'    when a dependency changes.
 #' 
 #'  \item Mimic ruby's autotest and rerun only failing tests until they pass,
-#'    and then rerun all test.
+#'    and then rerun all tests.
 #' }
 # 
 #' @seealso \code{\link{auto_test_package}}
@@ -28,13 +28,18 @@
 #' @param code_path path to directory containing code
 #' @param test_path path to directory containing tests
 #' @param reporter test reporter to use
+#' @param env environment in which to execute test suite. Defaults to new
+#'   environment inheriting from the global environment.
 #' @keywords debugging
-auto_test <- function(code_path, test_path, reporter = "summary") {
+auto_test <- function(code_path, test_path, reporter = "summary", env = NULL) {
   reporter <- find_reporter(reporter)
 
   # Start by loading all code and running all tests
-  source_dir(code_path)
-  test_dir(test_path)
+  if (is.null(env)) {
+    env <- new.env(parent = globalenv())
+  }
+  source_dir(code_path, env = env)
+  test_dir(test_path, env = env)
   
   starts_with <- function(string, prefix) {
     str_sub(string, 1, str_length(prefix)) == prefix
@@ -51,12 +56,13 @@ auto_test <- function(code_path, test_path, reporter = "summary") {
       # Reload code and rerun all tests
       cat("Changed code: ", str_c(basename(code), collapse = ", "), "\n")
       cat("Rerunning all tests\n")
-      lapply(code, source, chdir = TRUE)
-      test_dir(test_path)
+      source_dir(code_path, env = env)
+      test_dir(test_path, env = env)
     } else if (length(tests) > 0) {
       # If test changes, rerun just that test
       cat("Rerunning tests: ", str_c(basename(tests), collapse = ", "), "\n")      
-      with_reporter(reporter$clone(), lapply(tests, source, chdir = TRUE))
+      with_reporter(reporter$clone(), lapply(tests, sys.source, 
+        env = new.env(parent = env), chdir = TRUE))
     }
     
     TRUE
