@@ -44,15 +44,15 @@ with_reporter <- function(reporter, code) {
 #' @param reporter name of reporter
 #' @keywords internal
 find_reporter <- function(reporter) {
-  if (is.mutatr(reporter)) return(reporter)
+  if (mutatr::is.mutatr(reporter)) return(reporter)
   
   name <- reporter
-  substr(name, 1, 1) <- toupper(substr(name, 1, 1))
-  name <- paste(name, "Reporter", sep = "")
+  str_sub(name, 1, 1) <- toupper(str_sub(name, 1, 1))
+  name <- str_c(name, "Reporter")
   
   if (!exists(name)) {
     stop("Can not find test reporter ", reporter, call. = FALSE)
   }
   
-  get(name)
+  get(name)$clone()
 }
\ No newline at end of file
